# Module                       : _version.py
# Related program              : mh_universal_functions.py
# Author                       : MH
# Date                         : see _version.py
# Version                      : see _version.py
# Python Version, Mac OS X     : 3.7.7
# Python Version, Raspberry Pi : 3.7.7

__version__ = "2020.11.17.2"
